# AffinityStrategy

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**depend_on** | [**ObjectRef**](ObjectRef.md) |  | [optional] 
**policy** | **str** | Policy one of: \&quot;\&quot;, \&quot;Require\&quot;, \&quot;Prefer\&quot; | [optional] 
**prefers** | [**list[Prefer]**](Prefer.md) |  | [optional] 
**requires** | [**list[Require]**](Require.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


